ministry

package module
v1.9.23 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 21, 2026 License: MPL-2.0 Imports: 3 Imported by: 2

README

License

This project is licensed under the Mozilla Public License 2.0. See the LICENSE file for more details.

See the COPYRIGHT file for detailed copyright information.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Answer

type Answer struct {
	dcmgmt.Answer
	Name   string                `json:"name,omitempty"`
	Mnemo  string                `json:"mnemo.omitempty"`
	Person namesgenerator.Person `json:"person.omitempty"`
}

type VIPAnswer added in v1.9.2

type VIPAnswer struct {
	Answer
	TelegramID       int64     `json:"telegram_id,omitempty"`
	RequestID        uuid.UUID `json:"request_id,omitempty"`
	Lang             string    `json:"lang,omitempty"`
	VIPUpgradeNotify bool      `json:"vip_upgrade_notify,omitempty"`
}

type VIPReserve added in v1.9.1

type VIPReserve struct {
	RequestID uuid.UUID `json:"request_id"`
}

Directories

Path Synopsis
cmd
checkbrigadier command
ckfree command
ckvip command
ckvip-push command
createbrigade command
ministry-api command
ministry-api/docs
Package docs Code generated by swaggo/swag.
Package docs Code generated by swaggo/swag.
readmsgs command
readpush command
readpushvip command
recodesnapmap command
recodesnaps command
reqvipid command
reservebrigade command
synclabels command
syncstats command
internal
lockedfile
Package lockedfile creates and manipulates files whose contents should only change atomically.
Package lockedfile creates and manipulates files whose contents should only change atomically.
lockedfile/filelock
Package filelock provides a platform-independent API for advisory file locking.
Package filelock provides a platform-independent API for advisory file locking.
ssh

Jump to